@@ -1,21 +1,25 @@
 package App::Mobirc::Model::Channel;
-use Moose;
+use Mouse;
 use Scalar::Util qw/blessed/;
 use Carp;
 use List::MoreUtils qw/any all/;
 use App::Mobirc::Util;
 use App::Mobirc::Model::Message;
+use MIME::Base64::URLSafe;
+use Encode;
 
 has message_log => (
     is      => 'rw',
     isa     => 'ArrayRef',
     default => sub { +[] },
+    auto_deref => 1,
 );
 
 has recent_log => (
     is      => 'rw',
     isa     => 'ArrayRef',
     default => sub { +[] },
+    auto_deref => 1,
 );
 
 has topic => (
@@ -24,23 +28,12 @@ has topic => (
     default => '',
 );
 
-has global_context => (
-    is      => 'rw',
-    isa     => 'App::Mobirc',
-    default => sub { App::Mobirc->context },
-);
-
 has name => (
     is       => 'rw',
     isa      => 'Str',
     required => 1,
 );
 
-around 'new' => sub {
-    my ($next, $class, $trash, $name) = @_;
-    $next->($class, name => $name);
-};
-
 sub add_message {
     my ($self, $message) = @_;
 
@@ -55,9 +48,9 @@ sub add_message {
 
     # update keyword buffer.
     if ($message->class eq 'public' && $self->name ne '*keyword*') {
-        if ((any { $message->body =~ /$_/i } @{$self->{global_context}->config->{global}->{keywords} || []})
-         && (all { $message->body !~ /$_/i } @{$self->{global_context}->config->{global}->{stopwords} || ["\0"]})) {
-            App::Mobirc::Model::Channel->update_keyword_buffer($self->{global_context}, $message);
+        if ((any { $message->body =~ /$_/i } @{global_context->config->{global}->{keywords} || []})
+         && (all { $message->body !~ /$_/i } @{global_context->config->{global}->{stopwords} || ["\0"]})) {
+            App::Mobirc::Model::Channel->update_keyword_buffer($message);
         }
     }
 }
@@ -65,7 +58,7 @@ sub add_message {
 sub _add_to_log {
     my ($self, $key, $row) = @_;
 
-    my $log_max = $self->{global_context}->config->{httpd}->{lines};
+    my $log_max = global_context->config->{global}->{log_max} || 20;
 
     push @{$self->{$key}}, $row;
     if ( @{$self->{$key}} > $log_max ) {
@@ -74,12 +67,11 @@ sub _add_to_log {
 }
 
 sub update_keyword_buffer {
-    my ($class, $global_context, $message) = @_;
+    my ($class, $message) = @_;
     croak "this is class method" if blessed $class;
-    croak "global context required" unless blessed $global_context;
 
     DEBUG "UPDATE KEYWORD: $message";
-    $global_context->get_channel(U '*keyword*')->add_message( $message );
+    global_context->get_channel(U '*keyword*')->add_message( $message );
 }
 
 sub unread_lines {
@@ -99,10 +91,7 @@ sub clear_unread {
 sub post_command {
     my ($self, $command) = @_;
 
-    for my $code (@{$self->{global_context}->get_hook_codes('process_command')}) {
-        my $ret = $code->($self->{global_context}, $command, $self);
-        last if $ret;
-    }
+    global_context->run_hook_first('process_command', $command, $self);
 }
 
 sub recent_log_count {
@@ -110,6 +99,12 @@ sub recent_log_count {
     scalar @{ $self->recent_log };
 }
 
+sub name_urlsafe_encoded {
+    my $self = shift;
+    urlsafe_b64encode(encode_utf8 $self->name);
+}
+
+__PACKAGE__->meta->make_immutable;
 1;
 __END__
 
