@@ -2,7 +2,7 @@ package App::Mobirc::Web::C::Root;
 use App::Mobirc::Web::C;
 
 sub dispatch_index {
-    render_td();
+    render();
 }
 
 1;
